---
label: MCLUST
dockerfile:
wrapper:
notes: Not yet incorporated into SpikeForest
website: http://redishlab.neuroscience.umn.edu/MClust/MClust.html
source_code:
authors: A. David Redish
doi:
---

# MCLUST

## Description

## References